<button
        class="
    btn
    {% if type %} btn-{{ type }} {% endif %}
    {% if active }} btn-active {% endif %}
    {% if outline %} btn-outline {% endif %}
    {% if block %} btn-block {% endif %}
    {% if disabled %} btn-disabled {% endif %}
    {% if size %} btn-{{ size }} {% endif %}
    {% if wide %} btn-wide {% endif %}
    {% if square %} btn-square {% endif %}
    {% if circle %} btn-circle {% endif %}
    {% if no-animation %} btn-no-animation {% endif %}
    {{ class }}
"
>
    {{ slot }}
</button>