<span
        class="
        badge
        {% if type %} badge-{{ type }} {% endif %}
        {% if outline %} badge-outline {% endif %}
        {% if size %} badge-{{ size }} {% endif %}
        {{ class }}
">
    {{ slot }}
</span>